============================
vaultlocker service overview
============================
The vaultlocker service provides...

The vaultlocker service consists of the following components:

``vaultlocker-api`` service
  Accepts and responds to end user compute API calls...
